==> sweetpotato-0.6.0a0-py3-none-any.whl: sweetpotato/props/components_props.py <==
"""
Allowed props for React Native components.
"""
BUTTON_PROPS: set = {
    "color",
    "hasTVPreferredFocus",
    "touchSoundDisabled",
    "title",
    "onPress",
    "children",
}  #: Default allowed props for Button component.

IMAGE_PROPS: set = {
    "onPartialLoad",
    "onProgress",
    "onLoadStart",
    "onLoadEnd",
    "onError",
    "onLoad",
    "resizeMethod",
    "loadingIndicatorSource",
    "style",
    "source",
    "blurRadius",
    "progressiveRenderingEnabled",
    "defaultSource",
    "fadeDuration",
    "capInsets",
    "resizeMode",
}  #: Default allowed props for Image component.

NAVIGATION_PROPS: set = set()

SCROLL_VIEW_PROPS: set = {
    "StickyHeaderComponent",
    "alwaysBounceHorizontal",
    "alwaysBounceVertical",
    "automaticallyAdjustContentInsets",
    "automaticallyAdjustsScrollIndicatorInsets",
    "bounces",
    "bouncesZoom",
    "canCancelContentTouches",
    "centerContent",
    "contentContainerStyle",
    "contentInset",
    "contentInsetAdjustmentBehavior",
    "contentOffset",
    "decelerationRate",
    "directionalLockEnabled",
    "disableIntervalMomentum",
    "disableScrollViewPanResponder",
    "fadingEdgeLength",
    "horizontal",
    "indicatorStyle",
    "invertStickyHeaders",
    "keyboardDismissMode",
    "keyboardShouldPersistTaps",
    "maintainVisibleContentPosition",
    "maximumZoomScale",
    "minimumZoomScale",
    "nestedScrollEnabled",
    "onContentSizeChange",
    "onMomentumScrollBegin",
    "onScroll",
    "onScrollBeginDrag",
    "onScrollEndDrag",
    "onScrollToTop",
    "overScrollMode",
    "pagingEnabled",
    "persistentScrollbar",
    "pinchGestureEnabled",
    "refreshControl",
    "removeClippedSubviews",
    "scrollEnabled",
    "scrollIndicatorInsets",
    "scrollPerfTag",
    "scrollToOverflowEnabled",
    "scrollsToTop",
    "showsHorizontalScrollIndicator",
    "showsVerticalScrollIndicator",
    "snapToAlignment",
    "snapToEnd",
    "snapToInterval",
    "snapToStart",
    "stickyHeaderHiddenOnScroll",
    "stickyHeaderIndices",
    "zoomScale",
    # "scrollEventThrottle",
    # "snapToOffsets",
    # "onMomentumScrollEnd",
    # "endFillColor",
    # "decelerationRate",
    # "scrollsToTop",
    # "disableIntervalMomentum",
    # "alwaysBounceVertical",
    # "snapToAlignment",
    # "maximumZoomScale",
    # "scrollPerfTag",
    # "showsVerticalScrollIndicator",
    # "keyboardShouldPersistTaps",
    # "centerContent",
    # "nestedScrollEnabled",
    # "snapToEnd",
    # "snapToStart",
    # "disableScrollViewPanResponder",
    # "keyboardDismissMode",
    # "automaticallyAdjustContentInsets",
    # "contentOffset",
    # "StickyHeaderComponent",
    # "canCancelContentTouches",
    # "pagingEnabled",
    # "onScrollBeginDrag",
    # "minimumZoomScale",
    # "overScrollMode",
    # "onMomentumScrollBegin",
    # "stickyHeaderHiddenOnScroll",
    # "stickyHeaderIndices",
    # "contentInset",
    # "snapToInterval",
    # "persistentScrollbar",
    # "onScrollEndDrag",
    # "refreshControl",
    # "invertStickyHeaders",
    # "scrollIndicatorInsets",
    # "bounces",
    # "contentInsetAdjustmentBehavior",
    # "showsHorizontalScrollIndicator",
    # "directionalLockEnabled",
    # "contentContainerStyle",
    # "fadingEdgeLength",
    # "maintainVisibleContentPosition",
    # "alwaysBounceHorizontal",
    # "horizontal",
    # "onScrollToTop",
    # "bouncesZoom",
    # "zoomScale",
    # "scrollToOverflowEnabled",
    # "indicatorStyle",
    # "pinchGestureEnabled",
    # "automaticallyAdjustsScrollIndicatorInsets",
}  #: Default allowed props for ScrollView component.

FLAT_LIST_PROPS: set = set()  #: Default allowed props for FlatList component.

TEXT_PROPS: set = {
    "children",
    "accessibilityHint",
    "accessibilityLabel",
    "accessibilityRole",
    "accessibilityState",
    "accessibilityActions",
    "onAccessibilityAction",
    "accessible",
    "adjustsFontSizeToFit",
    "allowFontScaling",
    "android_hyphenationFrequency",
    "dataDetectorType",
    "disabled",
    "ellipsizeMode",
    "maxFontSizeMultiplier",
    "minimumFontScale",
    "nativeID",
    "numberOfLines",
    "onLayout",
    "onLongPress",
    "onMoveShouldSetResponder",
    "onPress",
    "onResponderGrant",
    "onResponderMove",
    "onResponderRelease",
    "onResponderTerminate",
    "onResponderTerminationRequest",
    "onStartShouldSetResponderCapture",
    "onTextLayout",
    "pressRetentionOffset",
    "selectable",
    "selectionColor",
    "suppressHighlighting",
    "textBreakStrategy",
    "style",
    "text"
    # "suppressHighlighting",
    # "ellipsizeMode",
    # "dataDetectorType",
    # "selectable",
    # "onTextLayout",
    # "android_hyphenationFrequency",
    # "adjustsFontSizeToFit",
    # "minimumFontScale",
    # "pressRetentionOffset",
    # "onLongPress",
}  #: Default allowed props for Text component.

TEXT_INPUT_PROPS: set = {
    "allowFontScaling",
    "autoCapitalize",
    "autoComplete",
    "autoCorrect",
    "autoFocus",
    "blurOnSubmit",
    "caretHidden",
    "clearButtonMode",
    "clearTextOnFocus",
    "contextMenuHidden",
    "dataDetectorTypes",
    "defaultValue",
    "disableFullscreenUI",
    "editable",
    "enablesReturnKeyAutomatically",
    "importantForAutofill",
    "inlineImageLeft",
    "inlineImagePadding",
    "inputAccessoryViewID",
    "keyboardAppearance",
    "keyboardType",
    "maxFontSizeMultiplier",
    "maxLength",
    "multiline",
    "numberOfLines",
    "onBlur",
    "onChange",
    "onChangeText",
    "onContentSizeChange",
    "onEndEditing",
    "onPressIn",
    "onPressOut",
    "onFocus",
    "onKeyPress",
    "onLayout",
    "onScroll",
    "onSelectionChange",
    "onSubmitEditing",
    "placeholder",
    "placeholderTextColor",
    "returnKeyLabel Android",
    "returnKeyType",
    "rejectResponderTermination",
    "scrollEnabled",
    "secureTextEntry",
    "selection",
    "selectionColor",
    "selectTextOnFocus",
    "showSoftInputOnFocus",
    "spellCheck",
    "textAlign",
    "textContentType",
    "passwordRules",
    "textBreakStrategy",
    "underlineColorAndroid",
    "value",
    # "onPressIn",
    # "secureTextEntry",
    # "returnKeyType",
    # "contextMenuHidden",
    # "placeholder",
    # "disableFullscreenUI",
    # "importantForAutofill",
    # "maxLength",
    # "spellCheck",
    # "editable",
    # "multiline",
    # "showSoftInputOnFocus",
    # "caretHidden",
    # "onEndEditing",
    # "onChange",
    # "textAlign",
    # "onSelectionChange",
    # "onSubmitEditing",
    # "defaultValue",
    # "onFocus",
    # "selection",
    # "autoCapitalize",
    # "rejectResponderTermination",
    # "keyboardType",
    # "autoFocus",
    # "onKeyPress",
    # "placeholderTextColor",
    # "returnKeyLabel Android",
    # "value",
    # "keyboardAppearance",
    # "onPressOut",
    # "enablesReturnKeyAutomatically",
    # "underlineColorAndroid",
    # "selectTextOnFocus",
    # "clearTextOnFocus",
    # "textContentType",
    # "passwordRules",
    # "inlineImagePadding",
    # "inlineImageLeft",
    # "blurOnSubmit",
    # "autoComplete",
    # "autoCorrect",
    # "clearButtonMode",
    # "dataDetectorTypes",
    # "onBlur",
    # "inputAccessoryViewID",
    # "onChangeText",
}  #: Default allowed props for TextInput component.

INPUT_PROPS: set = {
    "onChangeText",
    "placeholder",
    "value",
    "secureTextEntry",
}  #: Default allowed props for Input component.

VIEW_PROPS: set = {
    "functions",
    "accessibilityActions",
    "accessibilityElementsHidden",
    "accessibilityHint",
    "accessibilityIgnoresInvertColors",
    "accessibilityLabel",
    "accessibilityLiveRegion",
    "accessibilityRole",
    "accessibilityState",
    "accessibilityValue",
    "accessibilityViewIsModal",
    "accessible",
    "collapsable",
    "focusable",
    "hitSlop",
    "importantForAccessibility",
    "nativeID",
    "needsOffscreenAlphaCompositing",
    "nextFocusDown",
    "nextFocusForward",
    "nextFocusLeft",
    "nextFocusRight",
    "nextFocusUp",
    "onAccessibilityAction",
    "onAccessibilityEscape",
    "onAccessibilityTap",
    "onLayout",
    "onMagicTap",
    "onMoveShouldSetResponder",
    "onMoveShouldSetResponderCapture",
    "onResponderGrant",
    "onResponderMove",
    "onResponderReject",
    "onResponderRelease",
    "onResponderTerminate",
    "onResponderTerminationRequest",
    "onStartShouldSetResponder",
    "onStartShouldSetResponderCapture",
    "pointerEvents",
    "removeClippedSubviews",
    "renderToHardwareTextureAndroid",
    "shouldRasterizeIOS",
    "style",
    # "importantForAccessibility",
    # "hitSlop",
    # "focusable",
    # "collapsable",
    # "accessibilityElementsHidden",
    # "onAccessibilityTap",
    # "onStartShouldSetResponder",
    # "onMoveShouldSetResponderCapture",
    # "onResponderReject",
    # "pointerEvents",
    # "renderToHardwareTextureAndroid",
    # "shouldRasterizeIOS",
    # "accessibilityLiveRegion",
    # "accessibilityViewIsModal",
    # "needsOffscreenAlphaCompositing",
    # "accessibilityValue",
    # "accessibilityIgnoresInvertColors",
    # "onAccessibilityEscape",
    # "onMagicTap",
    "children",
}  #: Default allowed props for View component.

ACTIVITY_INDICATOR_PROPS: set = {
    # need to look at extending view props here
    "animating",
    "color",
    "hidesWhenStopped",
    "size",
}  #: Default allowed props for ActivityIndicator component.

TOUCHABLE_OPACITY_PROPS: set = (
    set()
)  #: Default allowed props for TouchableOpacity component.

STYLE_SHEET_PROPS: set = {"styles"}  #: Default allowed props for StyleSheet component.

APP_PROPS: set = {"state"}  #: Default allowed props for App component.

SAFE_AREA_PROVIDER_PROPS: set = {
    "children",
}  #: Default allowed props for SafeAreaProvider component.

==> sweetpotato-0.7.0a0-py3-none-any.whl: sweetpotato/props/components_props.py <==
"""
Allowed allowed_attributes for React Native components.
"""
BUTTON_PROPS: set[str] = {
    "color",
    "hasTVPreferredFocus",
    "touchSoundDisabled",
    "title",
    "onPress",
    "children",
    "accessibilityLanguage",
    "testID",
    "nextFocusForward",
    "accessibilityActions",
    "nextFocusLeft",
    "hasTvPreferredFocus",
    "onAccessibilityAction",
    "accessibilityLabel",
    "nextFocusUp",
    "disabled",
    "nextFocusRight",
    "nextFocusDown",
}  #: Default allowed allowed_attributes for Button component.

IMAGE_PROPS: set[str] = {
    "onPartialLoad",
    "onProgress",
    "onLoadStart",
    "onLoadEnd",
    "onError",
    "onLoad",
    "resizeMethod",
    "loadingIndicatorSource",
    "style",
    "source",
    "blurRadius",
    "progressiveRenderingEnabled",
    "defaultSource",
    "fadeDuration",
    "capInsets",
    "resizeMode",
    "onLayout",
    "accessibilityLabel",
    "accessible",
    "testID",
    "testId",
}  #: Default allowed allowed_attributes for Image component.

NAVIGATION_PROPS: set[str] = set()

SCROLL_VIEW_PROPS: set[str] = {
    "StickyHeaderComponent",
    "alwaysBounceHorizontal",
    "alwaysBounceVertical",
    "automaticallyAdjustContentInsets",
    "automaticallyAdjustsScrollIndicatorInsets",
    "bounces",
    "bouncesZoom",
    "canCancelContentTouches",
    "centerContent",
    "contentContainerStyle",
    "contentInset",
    "contentInsetAdjustmentBehavior",
    "contentOffset",
    "decelerationRate",
    "directionalLockEnabled",
    "disableIntervalMomentum",
    "disableScrollViewPanResponder",
    "fadingEdgeLength",
    "horizontal",
    "indicatorStyle",
    "invertStickyHeaders",
    "keyboardDismissMode",
    "keyboardShouldPersistTaps",
    "maintainVisibleContentPosition",
    "maximumZoomScale",
    "minimumZoomScale",
    "nestedScrollEnabled",
    "onContentSizeChange",
    "onMomentumScrollBegin",
    "onScroll",
    "onScrollBeginDrag",
    "onScrollEndDrag",
    "onScrollToTop",
    "overScrollMode",
    "pagingEnabled",
    "persistentScrollbar",
    "pinchGestureEnabled",
    "refreshControl",
    "removeClippedSubviews",
    "scrollEnabled",
    "scrollIndicatorInsets",
    "scrollPerfTag",
    "scrollToOverflowEnabled",
    "scrollsToTop",
    "showsHorizontalScrollIndicator",
    "showsVerticalScrollIndicator",
    "snapToAlignment",
    "snapToEnd",
    "snapToInterval",
    "snapToStart",
    "stickyHeaderHiddenOnScroll",
    "stickyHeaderIndices",
    "zoomScale",
    # "scrollEventThrottle",
    # "snapToOffsets",
    # "onMomentumScrollEnd",
    # "endFillColor",
    # "decelerationRate",
    # "scrollsToTop",
    # "disableIntervalMomentum",
    # "alwaysBounceVertical",
    # "snapToAlignment",
    # "maximumZoomScale",
    # "scrollPerfTag",
    # "showsVerticalScrollIndicator",
    # "keyboardShouldPersistTaps",
    # "centerContent",
    # "nestedScrollEnabled",
    # "snapToEnd",
    # "snapToStart",
    # "disableScrollViewPanResponder",
    # "keyboardDismissMode",
    # "automaticallyAdjustContentInsets",
    # "contentOffset",
    # "StickyHeaderComponent",
    # "canCancelContentTouches",
    # "pagingEnabled",
    # "onScrollBeginDrag",
    # "minimumZoomScale",
    # "overScrollMode",
    # "onMomentumScrollBegin",
    # "stickyHeaderHiddenOnScroll",
    # "stickyHeaderIndices",
    # "contentInset",
    # "snapToInterval",
    # "persistentScrollbar",
    # "onScrollEndDrag",
    # "refreshControl",
    # "invertStickyHeaders",
    # "scrollIndicatorInsets",
    # "bounces",
    # "contentInsetAdjustmentBehavior",
    # "showsHorizontalScrollIndicator",
    # "directionalLockEnabled",
    # "contentContainerStyle",
    # "fadingEdgeLength",
    # "maintainVisibleContentPosition",
    # "alwaysBounceHorizontal",
    # "horizontal",
    # "onScrollToTop",
    # "bouncesZoom",
    # "zoomScale",
    # "scrollToOverflowEnabled",
    # "indicatorStyle",
    # "pinchGestureEnabled",
    # "automaticallyAdjustsScrollIndicatorInsets",
}  #: Default allowed allowed_attributes for ScrollView component.

FLAT_LIST_PROPS: set[
    str
] = set()  #: Default allowed allowed_attributes for FlatList component.

TEXT_PROPS: set[str] = {
    "accessibilityHint",
    "accessibilityLanguage",
    "accessibilityLabel",
    "accessibilityRole",
    "accessibilityState",
    "accessibilityActions",
    "onAccessibilityAction",
    "accessible",
    "adjustsFontSizeToFit",
    "allowFontScaling",
    "androidHyphenationFrequency",
    "dataDetectorType",
    "disabled",
    "ellipsizeMode",
    "maxFontSizeMultiplier",
    "minimumFontScale",
    "nativeID",
    "numberOfLines",
    "onLayout",
    "onLongPress",
    "onMoveShouldSetResponder",
    "onPress",
    "onResponderGrant",
    "onResponderMove",
    "onResponderRelease",
    "onResponderTerminate",
    "onResponderTerminationRequest",
    "onStartShouldSetResponderCapture",
    "onTextLayout",
    "pressRetentionOffset",
    "selectable",
    "selectionColor",
    "style",
    "suppressHighlighting",
    "testID",
    "textBreakStrategy",
}  #: Default allowed props for Text component.

TEXT_INPUT_PROPS: set[str] = {
    "allowFontScaling",
    "autoCapitalize",
    "autoComplete",
    "autoCorrect",
    "autoFocus",
    "blurOnSubmit",
    "caretHidden",
    "cursorColor",
    "clearButtonMode",
    "clearTextOnFocus",
    "contextMenuHidden",
    "dataDetectorTypes",
    "defaultValue",
    "disableFullscreenUi",
    "editable",
    "enablesReturnKeyAutomatically",
    "importantForAutofill",
    "inlineImageLeft",
    "inlineImagePadding",
    "inputAccessoryViewId",
    "keyboardAppearance",
    "keyboardType",
    "maxFontSizeMultiplier",
    "maxLength",
    "multiline",
    "numberOfLines",
    "onBlur",
    "onChange",
    "onChangeText",
    "onContentSizeChange",
    "onEndEditing",
    "onPressIn",
    "onPressOut",
    "onFocus",
    "onKeyPress",
    "onKeyPreIme",
    "onLayout",
    "onScroll",
    "onSelectionChange",
    "onSubmitEditing",
    "placeholder",
    "placeholderTextColor",
    "returnKeyLabel Android",
    "returnKeyType",
    "returnKeyLabel",
    "rejectResponderTermination",
    "scrollEnabled",
    "secureTextEntry",
    "selection",
    "selectionColor",
    "selectTextOnFocus",
    "showSoftInputOnFocus",
    "spellCheck",
    "textAlign",
    "textContentType",
    "passwordRules",
    "textBreakStrategy",
    "underlineColorAndroid",
    "value",
    # "onPressIn",
    # "secureTextEntry",
    # "returnKeyType",
    # "contextMenuHidden",
    # "placeholder",
    # "disableFullscreenUI",
    # "importantForAutofill",
    # "maxLength",
    # "spellCheck",
    # "editable",
    # "multiline",
    # "showSoftInputOnFocus",
    # "caretHidden",
    # "onEndEditing",
    # "onChange",
    # "textAlign",
    # "onSelectionChange",
    # "onSubmitEditing",
    # "defaultValue",
    # "onFocus",
    # "selection",
    # "autoCapitalize",
    # "rejectResponderTermination",
    # "keyboardType",
    # "autoFocus",
    # "onKeyPress",
    # "placeholderTextColor",
    # "returnKeyLabel Android",
    # "value",
    # "keyboardAppearance",
    # "onPressOut",
    # "enablesReturnKeyAutomatically",
    # "underlineColorAndroid",
    # "selectTextOnFocus",
    # "clearTextOnFocus",
    # "textContentType",
    # "passwordRules",
    # "inlineImagePadding",
    # "inlineImageLeft",
    # "blurOnSubmit",
    # "autoComplete",
    # "autoCorrect",
    # "clearButtonMode",
    # "dataDetectorTypes",
    # "onBlur",
    # "inputAccessoryViewID",
    # "onChangeText",
}  #: Default allowed props for TextInput component.

INPUT_PROPS: set[str] = {
    "onChangeText",
    "placeholder",
    "value",
    "secureTextEntry",
}  #: Default allowed props for Input component.

VIEW_PROPS: set[str] = {
    "functions",
    "accessibilityActions",
    "accessibilityElementsHidden",
    "accessibilityHint",
    "accessibilityIgnoresInvertColors",
    "accessibilityLabel",
    "accessibilityLiveRegion",
    "accessibilityRole",
    "accessibilityState",
    "accessibilityValue",
    "accessibilityViewIsModal",
    "accessible",
    "collapsable",
    "focusable",
    "hitSlop",
    "importantForAccessibility",
    "nativeID",
    "needsOffscreenAlphaCompositing",
    "nextFocusDown",
    "nextFocusForward",
    "nextFocusLeft",
    "nextFocusRight",
    "nextFocusUp",
    "onAccessibilityAction",
    "onAccessibilityEscape",
    "onAccessibilityTap",
    "onLayout",
    "onMagicTap",
    "onMoveShouldSetResponder",
    "onMoveShouldSetResponderCapture",
    "onResponderGrant",
    "onResponderMove",
    "onResponderReject",
    "onResponderRelease",
    "onResponderTerminate",
    "onResponderTerminationRequest",
    "onStartShouldSetResponder",
    "onStartShouldSetResponderCapture",
    "pointerEvents",
    "removeClippedSubviews",
    "renderToHardwareTextureAndroid",
    "shouldRasterizeIOS",
    "style",
    # "importantForAccessibility",
    # "hitSlop",
    # "focusable",
    # "collapsable",
    # "accessibilityElementsHidden",
    # "onAccessibilityTap",
    # "onStartShouldSetResponder",
    # "onMoveShouldSetResponderCapture",
    # "onResponderReject",
    # "pointerEvents",
    # "renderToHardwareTextureAndroid",
    # "shouldRasterizeIOS",
    # "accessibilityLiveRegion",
    # "accessibilityViewIsModal",
    # "needsOffscreenAlphaCompositing",
    # "accessibilityValue",
    # "accessibilityIgnoresInvertColors",
    # "onAccessibilityEscape",
    # "onMagicTap",
    "children",
}  #: Default allowed props for View component.

ACTIVITY_INDICATOR_PROPS: set[str] = {
    # need to look at extending view props here
    "animating",
    "color",
    "hidesWhenStopped",
    "size",
}  #: Default allowed props for ActivityIndicator component.

TOUCHABLE_OPACITY_PROPS: set[
    str
] = set()  #: Default allowed props for TouchableOpacity component.

STYLE_SHEET_PROPS: set[str] = {
    "styles"
}  #: Default allowed props for StyleSheet component.

APP_PROPS: set[str] = {"state"}  #: Default allowed props for App component.

SAFE_AREA_PROVIDER_PROPS: set[str] = {
    "children",
}  #: Default allowed props for SafeAreaProvider component.
